[cfe-commits] r69166 - /cfe/trunk/tools/clang-cc/Warnings.cpp

Chris Lattner sabre at nondot.org
Wed Apr 15 07:42:02 PDT 2009


Author: lattner
Date: Wed Apr 15 09:42:02 2009
New Revision: 69166

URL: http://llvm.org/viewvc/llvm-project?rev=69166&view=rev
Log:
rename variable in comment, not just in code :).

Modified:
    cfe/trunk/tools/clang-cc/Warnings.cpp

Modified: cfe/trunk/tools/clang-cc/Warnings.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/tools/clang-cc/Warnings.cpp?rev=69166&r1=69165&r2=69166&view=diff

==============================================================================
--- cfe/trunk/tools/clang-cc/Warnings.cpp (original)
+++ cfe/trunk/tools/clang-cc/Warnings.cpp Wed Apr 15 09:42:02 2009
@@ -124,7 +124,7 @@
   // FIXME: -fdiagnostics-show-option
   // FIXME: -Wfatal-errors / -Wfatal-errors=foo
 
   /// ControlledOptions - Keep track of the options that the user explicitly
   /// poked with -Wfoo, -Wno-foo, or -Werror=foo.
   llvm::SmallVector<unsigned short, 256> ControlledDiags;
   
@@ -189,7 +189,7 @@
     for (const diag::kind *Member = Found->Members,
          *E = Found->Members+Found->NumMembers; Member != E; ++Member) {
       Diags.setDiagnosticMapping(*Member, Mapping);
-      assert(*Member < 65536 && "ControlledOptions element too small");
+      assert(*Member < 65536 && "ControlledDiags element too small");
       ControlledDiags.push_back(*Member);
     }
   }
@@ -210,7 +210,7 @@
 
     // Loop over all of the extension diagnostics.  Unless they were explicitly
     // controlled, reset their mapping to Mapping.  We walk through the
     // ControlledOptions in parallel with this walk, which is faster than
     // repeatedly binary searching it.
     //
     llvm::SmallVectorImpl<unsigned short>::iterator ControlledDiagsIt =
@@ -124,7 +124,7 @@
   // FIXME: -Wfatal-errors / -Wfatal-errors=foo
 
-  /// ControlledOptions - Keep track of the options that the user explicitly
+  /// ControlledDiags - Keep track of the options that the user explicitly
   /// poked with -Wfoo, -Wno-foo, or -Werror=foo.
   llvm::SmallVector<unsigned short, 256> ControlledDiags;
@@ -210,7 +210,7 @@
     // Loop over all of the extension diagnostics.  Unless they were explicitly
     // controlled, reset their mapping to Mapping.  We walk through the
-    // ControlledOptions in parallel with this walk, which is faster than
+    // ControlledDiags in parallel with this walk, which is faster than
     // repeatedly binary searching it.
     //





More information about the cfe-commits mailing list